@@ -18,7 +18,8 @@
 #include <QFileDialog>
 
 #include <KLocalizedString>
-#include <KRun>
+#include <KIO/JobUiDelegateFactory>
+#include <KIO/OpenUrlJob>
 #include <KDirWatch>
 
 //BEGIN BinUnitsModel
@@ -194,8 +195,11 @@ void BinUnitsView::contextMenuEvent(QContextMenuEvent *event)
 void BinUnitsView::mouseDoubleClicked(const QModelIndex& item)
 {
     //FIXME child processes don't notify us about changes ;(
-    if (item.column() < BinUnitsModel::Approved)
-        new KRun(QUrl::fromLocalFile(Project::instance()->absolutePath(item.data().toString())), this);
+    if (item.column() < BinUnitsModel::Approved) {
+        auto job = new KIO::OpenUrlJob(QUrl::fromLocalFile(Project::instance()->absolutePath(item.data().toString())));
+        job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+        job->start();
+    }
 }
 
 #include "moc_binunitsview.cpp"
