@@ -17,15 +17,57 @@
 #include "catalogitem.h"
 
 #include <QFile>
-#include <QTextCodec>
 #include <QList>
 #include <QTextStream>
 #include <QEventLoop>
 #include <QStringBuilder>
+#include <QRegularExpression>
 
 
 using namespace GettextCatalog;
 
+QStringList getTagBrNormal()
+{
+   #define qL(x) QLatin1String(x)
+   return (QStringList()
+       << qL("blockquote")
+       << qL("calloutlist")
+       << qL("center")
+       << qL("dd")
+       << qL("dl")
+       << qL("dt")
+       << qL("glosslist")
+       << qL("h1")
+       << qL("h2")
+       << qL("h3")
+       << qL("h4")
+       << qL("h5")
+       << qL("h6")
+       << qL("item")
+       << qL("itemizedlist")
+       << qL("li")
+       << qL("list")
+       << qL("listitem")
+       << qL("ol")
+       << qL("orderedlist")
+       << qL("p")
+       << qL("para")
+       << qL("pre")
+       << qL("seglistitem")
+       << qL("segmentedlist")
+       << qL("simplelist")
+       << qL("subtitle")
+       << qL("table")
+       << qL("td")
+       << qL("th")
+       << qL("title")
+       << qL("tr")
+       << qL("ul")
+       << qL("variablelist")
+       << qL("varlistentry"));
+   #undef qL
+}
+
 GettextExportPlugin::GettextExportPlugin(short wrapWidth, short trailingNewLines)
     : m_wrapWidth(wrapWidth)
     , m_trailingNewLines(trailingNewLines)
@@ -33,11 +75,10 @@ GettextExportPlugin::GettextExportPlugin(short wrapWidth, short trailingNewLines
 }
 
 ConversionStatus GettextExportPlugin::save(QIODevice* device,
-        const GettextStorage* catalog,
-        QTextCodec* codec)
+        const GettextStorage* catalog)
 {
     QTextStream stream(device);
-    stream.setCodec(codec);
+    stream.setEncoding(QStringConverter::Utf8);
 
     // only save header if it is not empty
     const QString& headerComment(catalog->m_header.comment());
@@ -156,7 +197,87 @@ void GettextExportPlugin::writeKeyword(QTextStream& stream, const QString& keywo
         realText.remove(QLatin1Char('\n'));
         stream << keyword << " \"" << realText << "\"\n";
         return;
-    } else if (m_wrapWidth <= 3) {
+    }
+
+    if (m_wrapWidth == -1) { // Special wrapping for KDE PO Summit (trunk/l10n-support/$(LANG)/summit)
+        QString realText(text);
+        realText.remove(QLatin1Char('\n'));
+        const QRegularExpression rx(QLatin1String(R"(<[^<>]*>|\\n|\\\\n)"), QRegularExpression::CaseInsensitiveOption);
+        QStringList list;
+        int pos = 0;
+        int startPos = 0;
+        bool closing = false;
+
+        QStringList tagBrNormal = getTagBrNormal();
+
+        while (true) {
+            const auto match = rx.match(realText, pos);
+            int nextPos = match.hasMatch() ? match.capturedStart() : -1;
+            if (nextPos == -1) {
+                list << realText.mid(startPos);
+                break;
+            }
+            int len = match.capturedLength();
+            pos = nextPos + len;
+            QString tag = realText.mid(nextPos, len);
+
+            if (tag == QLatin1String("\n") || tag == QLatin1String("\\n")) {
+                // break after
+                list << realText.mid(startPos, pos - startPos);
+                startPos = pos;
+            } else {
+                tag.remove(QLatin1Char(' '));
+                tag.remove(QLatin1Char('<'));
+                tag.remove(QLatin1Char('>'));
+                closing = false;
+
+                if (tag.contains(QLatin1Char('/'))) {
+                    tag.remove(QLatin1Char('/'));
+                    closing = true;
+                }
+
+                if (tag == QLatin1String("br") || tag == QLatin1String("hr") || tag == QLatin1String("nl")) {
+                    // break after
+                    list << realText.mid(startPos, pos - startPos);
+                    startPos = pos;
+                } else {
+                    for (const QString &item : tagBrNormal) {
+                        if (item == tag) {
+                            if (closing) {
+                                QString mid = realText.mid(startPos, pos - startPos);
+                                if (mid.length())
+                                    list << mid;
+                                startPos = pos;
+                            } else {
+                                QString mid = realText.mid(startPos, nextPos - startPos);
+                                if (mid.length())
+                                    list << mid;
+                                startPos = nextPos;
+                            }
+                            continue;
+                        }
+                    }
+                }
+            }
+        }
+
+        if (list.last().isEmpty())
+            list.removeLast();
+
+        if (list.count() == 1)  {
+            stream << keyword << QStringLiteral(" \"") << list.first() << QStringLiteral("\"\n");
+            return;
+        }
+
+        stream << keyword << QLatin1String(" \"\"\n");
+
+        for (const auto & item: std::as_const(list)) {
+            stream << QStringLiteral("\"") << item << QStringLiteral("\"\n");
+        }
+        return;
+    }
+
+    if (m_wrapWidth < 4) {
         // No change in wrapping
         QStringList list = text.split(QLatin1Char('\n'));
         if (list.count() > 1 || startedWithEmptyLine)
@@ -180,9 +301,9 @@ void GettextExportPlugin::writeKeyword(QTextStream& stream, const QString& keywo
     if (list.isEmpty())
         list.append(QString());
 
-    const QRegExp breakStopRe = containsHtml
-                              ? QRegExp(QStringLiteral("[ >%]"), Qt::CaseSensitive, QRegExp::Wildcard)
-                              : QRegExp(QStringLiteral("[ &%]"), Qt::CaseSensitive, QRegExp::Wildcard);
+    const QRegularExpression breakStopRe = containsHtml
+                              ? QRegularExpression(QRegularExpression::wildcardToRegularExpression(QStringLiteral("[ >%]")))
+                              : QRegularExpression(QRegularExpression::wildcardToRegularExpression(QStringLiteral("[ &%]")));
 
     int max = m_wrapWidth - 2;
     bool prependedEmptyLine = false;
@@ -193,7 +314,7 @@ void GettextExportPlugin::writeKeyword(QTextStream& stream, const QString& keywo
         }
 
         if (itm->length() > max) {
-            int pos = breakStopRe.lastIndexIn(*itm, max - 1);
+            auto pos = itm->lastIndexOf(breakStopRe, max - 1);
             if (pos > (max / 2)) {
                 int pos2 = itm->indexOf(QLatin1Char('<'), pos);
                 if (pos2 > 0 && pos2 < max - 1) {
