@@ -168,8 +168,8 @@ void SearchFileListView::scrollTo(const QString& file)
 
 bool SearchParams::isEmpty() const
 {
-    return sourcePattern.pattern().isEmpty()
-           && targetPattern.pattern().isEmpty();
+    return sourcePattern.isEmpty()
+           && targetPattern.isEmpty();
 }
 
 SearchJob::SearchJob(const QStringList& f, const SearchParams& sp, const QVector<Rule>& r, int sn, QObject*)
@@ -185,11 +185,15 @@ SearchJob::SearchJob(const QStringList& f, const SearchParams& sp, const QVector
 void SearchJob::run()
 {
     QElapsedTimer a; a.start();
-    bool removeAmpFromSource = searchParams.sourcePattern.patternSyntax() == QRegExp::FixedString
-                               && !searchParams.sourcePattern.pattern().contains(QLatin1Char('&'));
-    bool removeAmpFromTarget = searchParams.targetPattern.patternSyntax() == QRegExp::FixedString
-                               && !searchParams.targetPattern.pattern().contains(QLatin1Char('&'));
-    for (const QString& filePath : qAsConst(files)) {
+    bool removeAmpFromSource = !searchParams.isRegEx
+                               && !searchParams.sourcePattern.contains(QLatin1Char('&'));
+    bool removeAmpFromTarget = !searchParams.isRegEx
+                               && !searchParams.targetPattern.contains(QLatin1Char('&'));
+
+    const auto sourceRegEx = QRegularExpression(searchParams.isRegEx ? searchParams.sourcePattern : QRegularExpression::escape(searchParams.sourcePattern), searchParams.regExOptions);
+    const auto targetRegEx = QRegularExpression(searchParams.isRegEx ? searchParams.targetPattern : QRegularExpression::escape(searchParams.targetPattern), searchParams.regExOptions);
+
+    for (const QString& filePath : std::as_const(files)) {
         Catalog catalog(nullptr);
         if (Q_UNLIKELY(catalog.loadFromUrl(filePath, QString(), &m_size, true) != 0))
             continue;
@@ -202,24 +206,30 @@ void SearchJob::run()
             //    return false;
             int lim = catalog.isPlural(pos.entry) ? catalog.numberOfPluralForms() : 1;
             for (pos.form = 0; pos.form < lim; pos.form++) {
-                int sp = 0;
-                int tp = 0;
-                if (!searchParams.sourcePattern.isEmpty())
-                    sp = searchParams.sourcePattern.indexIn(removeAmpFromSource ? catalog.source(pos).remove(QLatin1Char('&')) : catalog.source(pos));
-                if (!searchParams.targetPattern.isEmpty())
-                    tp = searchParams.targetPattern.indexIn(removeAmpFromTarget ? catalog.target(pos).remove(QLatin1Char('&')) : catalog.target(pos));
+                QRegularExpressionMatch sourceMatch;
+                QRegularExpressionMatch targetMatch;
+                bool hasSourceMatch = true;
+                bool hasTargetMatch = true;
+                if (!searchParams.sourcePattern.isEmpty()) {
+                    sourceMatch = sourceRegEx.match(removeAmpFromSource ? catalog.source(pos).remove(QLatin1Char('&')) : catalog.source(pos));
+                    hasSourceMatch = sourceMatch.hasMatch() != searchParams.invertSource;
+                }
+                if (!searchParams.targetPattern.isEmpty()) {
+                    targetMatch = targetRegEx.match(removeAmpFromTarget ? catalog.target(pos).remove(QLatin1Char('&')) : catalog.target(pos));
+                    hasTargetMatch = targetMatch.hasMatch() != searchParams.invertTarget;
+                }
                 //int np=searchParams.notesPattern.indexIn(catalog.notes(pos));
 
-                if ((sp != -1) != searchParams.invertSource && (tp != -1) != searchParams.invertTarget) {
+                if (hasSourceMatch && hasTargetMatch) {
                     //TODO handle multiple results in same column
                     //FileSearchResult r;
                     SearchResult r;
                     r.filepath = filePath;
                     r.docPos = DocPos(pos);
                     if (!searchParams.sourcePattern.isEmpty() && !searchParams.invertSource)
-                        r.sourcePositions << StartLen(searchParams.sourcePattern.pos(), searchParams.sourcePattern.matchedLength());
+                        r.sourcePositions << StartLen(sourceMatch.capturedStart(), sourceMatch.capturedLength());
                     if (!searchParams.targetPattern.isEmpty() && !searchParams.invertTarget)
-                        r.targetPositions << StartLen(searchParams.targetPattern.pos(), searchParams.targetPattern.matchedLength());
+                        r.targetPositions << StartLen(targetMatch.capturedStart(), targetMatch.capturedLength());
                     r.source = catalog.source(pos);
                     r.target = catalog.target(pos);
                     r.state = catalog.state(pos);
@@ -250,7 +260,7 @@ void SearchJob::run()
     Q_EMIT done(this);
 }
 
-MassReplaceJob::MassReplaceJob(const SearchResults& srs, int pos, const QRegExp& s, const QString& r, QObject*)
+MassReplaceJob::MassReplaceJob(const SearchResults& srs, int pos, const QRegularExpression& s, const QString& r, QObject*)
     : QRunnable()
     , searchResults(srs)
     , globalPos(pos)
@@ -282,23 +292,25 @@ void MassReplaceJob::run()
             }
 
             CatalogString s = catalog.targetWithTags(docPos);
-            int pos = replaceWhat.indexIn(s.string);
+            auto match = replaceWhat.match(s.string);
+            int pos = match.hasMatch() ? match.capturedStart() : -1;
             while (pos != -1) {
-                if (!s.string.midRef(pos, replaceWhat.matchedLength()).contains(TAGRANGE_IMAGE_SYMBOL)) {
+                if (!QStringView(s.string).mid(pos, match.capturedLength()).contains(TAGRANGE_IMAGE_SYMBOL)) {
                     docPos.offset = pos;
-                    catalog.targetDelete(docPos, replaceWhat.matchedLength());
+                    catalog.targetDelete(docPos, match.capturedLength());
                     catalog.targetInsert(docPos, replaceWith);
-                    s.string.replace(pos, replaceWhat.matchedLength(), replaceWith);
+                    s.string.replace(pos, match.capturedLength(), replaceWith);
                     pos += replaceWith.length();
                 } else {
-                    pos += replaceWhat.matchedLength();
+                    pos += match.capturedLength();
                     qCWarning(LOKALIZE_LOG) << "skipping replace because matched text contains markup" << s.string;
                 }
 
                 if (pos > s.string.length() || replaceWhat.pattern().startsWith(QLatin1Char('^')))
                     break;
 
-                pos = replaceWhat.indexIn(s.string, pos);
+                match = replaceWhat.match(s.string, pos);
+                pos = match.hasMatch() ? match.capturedStart() : -1;
             }
         }
 
@@ -366,7 +378,7 @@ QVariant FileSearchModel::data(const QModelIndex& item, int role) const
             const QString startBldTag = QStringLiteral("<b >");
             const QString endBldTag = QStringLiteral("</b >");
 
-            if (item.column() == FileSearchModel::Target && !m_replaceWhat.isEmpty()) {
+            if (item.column() == FileSearchModel::Target && !m_replaceWhat.pattern().isEmpty()) {
                 result.replace(m_replaceWhat, m_replaceWith);
                 QString escaped = convertToHtml(result, !sr.isApproved);
                 escaped.replace(startBld, startBldTag);
@@ -401,7 +413,7 @@ QVariant FileSearchModel::data(const QModelIndex& item, int role) const
     return QVariant();
 }
 
-void FileSearchModel::setReplacePreview(const QRegExp& s, const QString& r)
+void FileSearchModel::setReplacePreview(const QRegularExpression& s, const QString& r)
 {
     m_replaceWhat = s;
     m_replaceWith = QLatin1String("_ST_") + r + QLatin1String("_END_");
@@ -427,7 +439,7 @@ FileSearchTab::FileSearchTab(QWidget *parent)
     setCentralWidget(w);
 
 
-    QShortcut* sh = new QShortcut(Qt::ControlModifier + Qt::Key_L, this);
+    QShortcut* sh = new QShortcut(Qt::ControlModifier | Qt::Key_L, this);
     connect(sh, &QShortcut::activated, ui_fileSearchOptions->querySource, qOverload<>(&QLineEdit::setFocus));
     setFocusProxy(ui_fileSearchOptions->querySource);
 
@@ -453,13 +465,13 @@ FileSearchTab::FileSearchTab(QWidget *parent)
     view->setContextMenuPolicy(Qt::ActionsContextMenu);
 
     QAction* a = new QAction(i18n("Copy source to clipboard"), view);
-    a->setShortcut(Qt::ControlModifier + Qt::Key_S);
+    a->setShortcut(Qt::ControlModifier | Qt::Key_S);
     a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     connect(a, &QAction::triggered, this, &FileSearchTab::copySourceToClipboard);
     view->addAction(a);
 
     a = new QAction(i18n("Copy target to clipboard"), view);
-    a->setShortcut(QKeySequence(Qt::ControlModifier + Qt::Key_Return));
+    a->setShortcut(QKeySequence(Qt::ControlModifier | Qt::Key_Return));
     a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     connect(a, &QAction::triggered, this, &FileSearchTab::copyTargetToClipboard);
     view->addAction(a);
@@ -557,8 +569,8 @@ void FileSearchTab::performSearch()
     m_lastSearchNumber++;
 
     SearchParams sp;
-    sp.sourcePattern.setPattern(ui_fileSearchOptions->querySource->text());
-    sp.targetPattern.setPattern(ui_fileSearchOptions->queryTarget->text());
+    sp.sourcePattern = ui_fileSearchOptions->querySource->text();
+    sp.targetPattern = ui_fileSearchOptions->queryTarget->text();
     sp.invertSource = ui_fileSearchOptions->invertSource->isChecked();
     sp.invertTarget = ui_fileSearchOptions->invertTarget->isChecked();
 
@@ -567,10 +579,7 @@ void FileSearchTab::performSearch()
     if (sp.isEmpty() && rules.isEmpty())
         return;
 
-    if (!ui_fileSearchOptions->regEx->isChecked()) {
-        sp.sourcePattern.setPatternSyntax(QRegExp::FixedString);
-        sp.targetPattern.setPatternSyntax(QRegExp::FixedString);
-    }
+    sp.isRegEx = ui_fileSearchOptions->regEx->isChecked();
     /*
         else
         {
@@ -579,8 +588,7 @@ void FileSearchTab::performSearch()
         }
     */
     if (!ui_fileSearchOptions->matchCase->isChecked()) {
-        sp.sourcePattern.setCaseSensitivity(Qt::CaseInsensitive);
-        sp.targetPattern.setCaseSensitivity(Qt::CaseInsensitive);
+        sp.regExOptions = QRegularExpression::CaseInsensitiveOption;
     }
     stopSearch();
 
@@ -602,14 +610,14 @@ void FileSearchTab::performSearch()
 
 void FileSearchTab::stopSearch()
 {
-    for (auto job : qAsConst(m_runningJobs)) {
+    for (auto job : std::as_const(m_runningJobs)) {
         [[maybe_unused]] const bool result = QThreadPool::globalInstance()->tryTake(job);
     }
     m_runningJobs.clear();
 }
 
 
-void FileSearchTab::massReplace(const QRegExp &what, const QString& with)
+void FileSearchTab::massReplace(const QRegularExpression &what, const QString& with)
 {
 #define BATCH_SIZE 20
 
@@ -824,10 +832,19 @@ MassReplaceView::~MassReplaceView()
     delete ui;
 }
 
-static QRegExp regExpFromUi(const QString& s, Ui_MassReplaceOptions* ui)
+static QRegularExpression regExpFromUi(const QString& s, Ui_MassReplaceOptions* ui)
 {
-    return QRegExp(s, ui->matchCase->isChecked() ? Qt::CaseSensitive : Qt::CaseInsensitive,
-                   ui->useRegExps->isChecked() ? QRegExp::RegExp : QRegExp::FixedString);
+    QRegularExpression rx;
+    if (ui->useRegExps->isChecked()) {
+        rx.setPattern(s);
+    } else {
+        rx.setPattern(QRegularExpression::escape(s));
+    }
+    if (!ui->matchCase->isChecked()) {
+        rx.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
+    }
+
+    return rx;
 }
 
 void MassReplaceView::requestPreviewUpdate()
@@ -857,7 +874,7 @@ void MassReplaceView::requestPreview(bool enable)
         disconnect(ui->useRegExps, &QCheckBox::toggled, this, &MassReplaceView::requestPreviewUpdate);
         disconnect(ui->matchCase, &QCheckBox::toggled, this, &MassReplaceView::requestPreviewUpdate);
 
-        Q_EMIT previewRequested(QRegExp(), QString());
+        Q_EMIT previewRequested(QRegularExpression(), QString());
     }
 }
 
