@@ -36,29 +36,28 @@
 class PoItemDelegate: public QStyledItemDelegate
 {
 public:
-    PoItemDelegate(QObject *parent = nullptr);
-    ~PoItemDelegate() {}
+    explicit PoItemDelegate(QObject *parent = nullptr);
+    ~PoItemDelegate() = default;
     void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
     QString displayText(const QVariant & value, const QLocale & locale) const override;
     QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const override;
 private:
-    KColorScheme m_colorScheme;
+    KColorScheme m_colorScheme{QPalette::Normal};
 };
 
 PoItemDelegate::PoItemDelegate(QObject *parent)
     : QStyledItemDelegate(parent)
-    , m_colorScheme(QPalette::Normal)
 {}
 
 QSize PoItemDelegate::sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const
 {
     QString text = index.data().toString();
     int lineCount = 1;
-    int nPos = text.indexOf('\n');
+    int nPos = text.indexOf(QLatin1Char('\n'));
     if (nPos == -1)
         nPos = text.size();
     else
-        lineCount += text.count('\n');
+        lineCount += text.count(QLatin1Char('\n'));
     static QFontMetrics metrics(option.font);
     return QSize(metrics.averageCharWidth() * nPos, metrics.height() * lineCount);
 }
@@ -115,7 +114,7 @@ void PoItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option
 
 // Temporary workaround for Qt bug https://bugreports.qt.io/browse/QTBUG-78094
 // to ensure that large numbers are formatted using a thousands separator
-QString PoItemDelegate::displayText(const QVariant & value, const QLocale & locale) const
+QString PoItemDelegate::displayText(const QVariant & value, [[maybe_unused]] const QLocale & locale) const
 {
     return QStyledItemDelegate::displayText(value, QLocale::system());
 }
@@ -126,7 +125,7 @@ QString PoItemDelegate::displayText(const QVariant & value, const QLocale & loca
 class SortFilterProxyModel : public KDirSortFilterProxyModel
 {
 public:
-    SortFilterProxyModel(QObject* parent = nullptr)
+    explicit SortFilterProxyModel(QObject* parent = nullptr)
         : KDirSortFilterProxyModel(parent)
     {
         connect(Project::instance()->model(), &ProjectModel::totalsChanged, this, &SortFilterProxyModel::invalidate);
@@ -304,7 +303,7 @@ ProjectWidget::ProjectWidget(/*Catalog* catalog, */QWidget* parent)
     new HeaderViewMenuHandler(header());
 
     KConfig config;
-    KConfigGroup stateGroup(&config, "ProjectWindow");
+    KConfigGroup stateGroup(&config, QStringLiteral("ProjectWindow"));
     header()->restoreState(QByteArray::fromBase64(stateGroup.readEntry("ListHeaderState", QByteArray())));
     i = sizeof(widthDefaults) / sizeof(int);
     while (--i >= 0) {
@@ -318,7 +317,7 @@ ProjectWidget::ProjectWidget(/*Catalog* catalog, */QWidget* parent)
 ProjectWidget::~ProjectWidget()
 {
     KConfig config;
-    KConfigGroup stateGroup(&config, "ProjectWindow");
+    KConfigGroup stateGroup(&config, QStringLiteral("ProjectWindow"));
     stateGroup.writeEntry("ListHeaderState", header()->saveState().toBase64());
 }
 
@@ -335,7 +334,7 @@ void ProjectWidget::modelReloaded()
         if (setCurrentItem(m_currentItemPathBeforeReload))
             break;
     }
-    if (proxyModel()->filterRegExp().pattern().size() > 2)
+    if (proxyModel()->filterRegularExpression().pattern().size() > 2)
         expandItems();
 }
 
@@ -543,3 +542,4 @@ QSortFilterProxyModel* ProjectWidget::proxyModel()
     return m_proxyModel;
 }
 
+#include "moc_projectwidget.cpp"
